@@ -8,7 +8,7 @@ use AutoLoader;
 use Exporter;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 require XSLoader;
 XSLoader::load('DDC::XS', $VERSION);
@@ -24,7 +24,9 @@ require DDC::XS::Object;         ##-- global wrappers
 require DDC::XS::Constants;      ##-- sets up DDC::XS::EXPORTS etc.
 require DDC::XS::CQueryCompiler;
 #require DDC::XS::CQuery;
-#require DDC::XS::CQFilter;
+#require DDC::XS::CQCount;
+require DDC::XS::CQFilter;
+require DDC::XS::CQueryOptions;
 
 ##======================================================================
 ## Globals
